#
# spec file for package python-nbsmoke
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python39 1
Name:           python-nbsmoke
Version:        0.6.0
Release:        5.1
Summary:        Basic notebook checks
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/holoviz-dev/nbsmoke
Source:         https://files.pythonhosted.org/packages/source/n/nbsmoke/nbsmoke-%{version}.tar.gz
# PATCH-FIX-UPSTREAM nbsmoke-pr63-remove-id.patch gh#pyviz-dev/nbsmoke#63
Patch0:         nbsmoke-pr63-remove-id.patch
# PATCH-FIX-OPENSUSE nbsmoke-obs-nounraisableexception.patch, don't error on warnings about obs not closing sockets in time, code@bnavigator.de
Patch1:         nbsmoke-obs-nounraisableexception.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-ipykernel
Requires:       python-jupyter-client
Requires:       python-nbconvert
Requires:       python-nbformat
Requires:       python-param
Requires:       python-pyflakes
Requires:       python-pytest >= 3.1.1
Recommends:     python-beautifulsoup4
Recommends:     python-requests
Provides:       python-jupyter_nbsmoke = %{version}
Obsoletes:      python-jupyter_nbsmoke < %{version}
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module beautifulsoup4}
BuildRequires:  %{python_module ipykernel}
BuildRequires:  %{python_module jupyter-client}
BuildRequires:  %{python_module nbconvert}
BuildRequires:  %{python_module nbformat}
BuildRequires:  %{python_module param}
BuildRequires:  %{python_module pyflakes}
BuildRequires:  %{python_module pytest >= 3.1.1}
BuildRequires:  %{python_module requests}
# /SECTION
%if "%{python_flavor}" == "python3" || "%{?python_provides}"  == "python3"
Provides:       jupyter-nbsmoke = %{version}
%endif
%python_subpackages

%description
Basic notebook smoke tests for checking whether the notebooks run,
and whether they contain lint.

%prep
%autosetup -p1 -n nbsmoke-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# needs to import from sourcedir
export PYTHONPATH=":x"
# fails to check unicode strings
donttest="test_run_good_html"
%pytest -p pytester -k "not ($donttest)"

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/nbsmoke-%{version}.dist-info
%{python_sitelib}/nbsmoke/

%changelog
* Fri Mar  8 2024 Ben Greiner <code@bnavigator.de>
- Skip python39: no longer supported since ipython 8.19
* Fri Aug 11 2023 Ben Greiner <code@bnavigator.de>
- Ignore test failure due to new unicode handling in the stack
* Mon Oct 17 2022 Ben Greiner <code@bnavigator.de>
- Add nbsmoke-pr63-remove-id.patch -- gh#pyviz-dev/nbsmoke#63
* Fri Jun 24 2022 Ben Greiner <code@bnavigator.de>
- Add nbsmoke-obs-nounraisableexception.patch: don't error on
  warnings about obs not closing sockets in time
* Sat Jan  8 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.6.0
  * Change template file name for nbconvert >= 6
* Sun Nov 14 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.5.0
  * Compatibility with newer versions of pytest.
  * Compatibility with newer versions of nbconvert.
  * Allow user-specified magic handlers.
- Enable test suite
* Tue Dec 15 2020 Benjamin Greiner <code@bnavigator.de>
- Provide the old jupyter package name only for the primary
  Python3 interpreter -- gh#openSUSE/python-rpm-macros#66
* Fri Jan  3 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.4.1
  * Don't completely fail to import if beautifulsoup4 and requests
    are unavailable (only the "verify" functionality requires them;
    beautifulsoup4 and requests are supposed to be optional
    dependencies).
- Update to 0.4.0
  * The dependencies for the "verify" command are now optional;
    pip users wanting this feature will need to add the "verify"
    extra (pip install nbsmoke[verify] or pip install nbsmoke[all]),
    or add the dependencies manually (pip install requests
    beautifulsoup4).
  * The dependency for holoviews magics lint checking (i.e.
    holoviews) is now optional; pip users wanting this feature will
    need to add the "holoviews-magics" extra (pip install
    nbsmoke[holoviews-magics] or pip install nbsmoke[all]), or add
    the dependency manually (pip install holoviews).
  * Bug fix: Avoid importing holoviews if available when nbsmoke is
    imported (#36). Previously, the mere presence of nbsmoke in an
    environment could affect test coverage measurement for projects
    that holoviews itself imports.
- Update to 0.3.0
  * support for flake messages to ignore (by regex)
  * support for magics blacklist (i.e. magics that if present cause a flake)
  * added support for script & capture cell magics (mainly as a demo)
  * increased the number of builtin magics that will be silently
    ignored (as they don't interact with the python process), e.g.
    bookmark, edit, who, etc
  * lint failures can be set to be warnings only (potentially
    useful for systems that report warnings
- Drop python2 support due to dependencies dropping python2
* Wed Nov 13 2019 Todd R <toddrme2178@gmail.com>
- jupyter_client renamed to jupyter-client
* Wed Jun 12 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.2.8
  * Shorter lint tracebacks
  * Added --nbsmoke-lint-onlywarn: Report lint failures as warnings
  * Added --nbsmoke-lint-debug: Allow easier investigation (and debugging) of lint failures. nbsmoke lint currently uses nbconvert to convert ipynb to py, then runs pyflakes on that. You can now see the py source that was actually flake checked (pyflakes-reported line numbers correspond to this source). (Note: unhandled magics e.g. from holoviews can cause spurious flakes. I have separate changes that attempt to improve the situation. Meanwhile, this option is also helpful for debugging that situation.)
  * Only supporting html storage in python 3.
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Rename to to match python package naming guidelines.
* Thu Aug  2 2018 toddrme2178@gmail.com
- Update to 0.2.7
  * Support nb verify on python 27
  * Ensure verify links with a bad domain remains a warning.
  * Fix skip matching on windows
  * Hacked in way to support two groups of notebooks.
* Thu Jun  7 2018 jengelh@inai.de
- Replace rhetoric questions in descriptions.
* Fri Apr 20 2018 toddrme2178@gmail.com
- Initial version
